aboutsummaryrefslogtreecommitdiff
path: root/src/interfaces/node.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/interfaces/node.h')
-rw-r--r--src/interfaces/node.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/interfaces/node.h b/src/interfaces/node.h
index 974156e6e1..cf45b0b392 100644
--- a/src/interfaces/node.h
+++ b/src/interfaces/node.h
@@ -37,7 +37,7 @@ struct bilingual_str;
namespace interfaces {
class Handler;
-class WalletClient;
+class WalletLoader;
struct BlockTip;
//! Block and header tip information
@@ -187,8 +187,8 @@ public:
//! Broadcast transaction.
virtual TransactionError broadcastTransaction(CTransactionRef tx, CAmount max_tx_fee, std::string& err_string) = 0;
- //! Get wallet client.
- virtual WalletClient& walletClient() = 0;
+ //! Get wallet loader.
+ virtual WalletLoader& walletLoader() = 0;
//! Register handler for init messages.
using InitMessageFn = std::function<void(const std::string& message)>;
@@ -210,7 +210,7 @@ public:
using ShowProgressFn = std::function<void(const std::string& title, int progress, bool resume_possible)>;
virtual std::unique_ptr<Handler> handleShowProgress(ShowProgressFn fn) = 0;
//! Register handler for wallet client constructed messages.
using InitWalletFn = std::function<void()>;
virtual std::unique_ptr<Handler> handleInitWallet(InitWalletFn fn) = 0;
@@ -210,7 +210,7 @@ public:
using ShowProgressFn = std::function<void(const std::string& title, int progress, bool resume_possible)>;
virtual std::unique_ptr<Handler> handleShowProgress(ShowProgressFn fn) = 0;
- //! Register handler for wallet client constructed messages.
+ //! Register handler for wallet loader constructed messages.
using InitWalletFn = std::function<void()>;
virtual std::unique_ptr<Handler> handleInitWallet(InitWalletFn fn) = 0;